==> microcms-richedit-processer-0.6.0.tgz: package/esm/processers/iframe.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var iframeProcesser = function (iframeElement, options) { return __awaiter(void 0, void 0, void 0, function () {
    var attributes_1, classNames, src, width, height, divElement;
    var _a, _b, _c, _d;
    return __generator(this, function (_e) {
        if (options.iframe.addAttribute !== undefined) {
            attributes_1 = options.iframe.addAttribute;
            Object.keys(attributes_1).forEach(function (key) {
                iframeElement.setAttribute(key, attributes_1[key]);
            });
        }
        if (options.iframe.addClassName !== undefined) {
            classNames = options.iframe.addClassName;
            classNames.forEach(function (className) {
                iframeElement.classList.add(className);
            });
        }
        if (options.iframe.provider === 'lazysizes') {
            if (options.iframe.lazy) {
                src = iframeElement.getAttribute('src');
                if (src === undefined) {
                    throw Error('Some of the iframe tags do not have src set.');
                }
                iframeElement.setAttribute('data-src', src);
                iframeElement.removeAttribute('src');
                iframeElement.classList.add('lazyload');
            }
        }
        width = (_b = (_a = options.iframe.width) !== null && _a !== void 0 ? _a : Number(iframeElement.getAttribute('width'))) !== null && _b !== void 0 ? _b : 640;
        height = (_d = (_c = options.iframe.height) !== null && _c !== void 0 ? _c : Number(iframeElement.getAttribute('height'))) !== null && _d !== void 0 ? _d : 360;
        iframeElement.setAttribute('width', width.toString());
        iframeElement.setAttribute('height', height.toString());
        iframeElement.setAttribute('style', 'position: absolute; width: 100%; height: 100%; top: 0; left: 0;');
        divElement = "<div style=\"position: relative; padding-bottom: calc(" + height + " / " + width + " * 100%);\">" + iframeElement.outerHTML + "</div>";
        iframeElement.insertAdjacentHTML('beforebegin', divElement);
        iframeElement.remove();
        return [2 /*return*/];
    });
}); };
export default iframeProcesser;

==> microcms-richedit-processer-1.0.2.tgz: package/esm/processers/iframe.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var iframeProcesser = function (iframeElement, options) { return __awaiter(void 0, void 0, void 0, function () {
    var attributes_1, classNames, src, width, height, divElement;
    var _a, _b, _c, _d;
    return __generator(this, function (_e) {
        if (options.iframe.addAttributes !== undefined) {
            attributes_1 = options.iframe.addAttributes;
            Object.keys(attributes_1).forEach(function (key) {
                iframeElement.setAttribute(key, attributes_1[key]);
            });
        }
        if (options.iframe.addClassName !== undefined) {
            classNames = options.iframe.addClassName;
            classNames.forEach(function (className) {
                iframeElement.classList.add(className);
            });
        }
        if (options.iframe.provider === 'lazysizes') {
            if (options.iframe.lazy) {
                src = iframeElement.getAttribute('src');
                if (src === undefined) {
                    throw Error('Some of the iframe tags do not have src set.');
                }
                iframeElement.setAttribute('data-src', src);
                iframeElement.removeAttribute('src');
                iframeElement.classList.add('lazyload');
            }
        }
        width = (_b = (_a = options.iframe.width) !== null && _a !== void 0 ? _a : Number(iframeElement.getAttribute('width'))) !== null && _b !== void 0 ? _b : 640;
        height = (_d = (_c = options.iframe.height) !== null && _c !== void 0 ? _c : Number(iframeElement.getAttribute('height'))) !== null && _d !== void 0 ? _d : 360;
        iframeElement.setAttribute('width', width.toString());
        iframeElement.setAttribute('height', height.toString());
        iframeElement.setAttribute('style', 'position: absolute; width: 100%; height: 100%; top: 0; left: 0;');
        divElement = "<div style=\"position: relative; padding-bottom: calc(" + height + " / " + width + " * 100%);\">" + iframeElement.outerHTML + "</div>";
        iframeElement.insertAdjacentHTML('beforebegin', divElement);
        iframeElement.remove();
        return [2 /*return*/];
    });
}); };
export default iframeProcesser;
